summaryrefslogtreecommitdiffstats
path: root/libk9copy/backupdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libk9copy/backupdlg.cpp')
-rw-r--r--libk9copy/backupdlg.cpp138
1 files changed, 69 insertions, 69 deletions
diff --git a/libk9copy/backupdlg.cpp b/libk9copy/backupdlg.cpp
index a124c9f..1cc01d2 100644
--- a/libk9copy/backupdlg.cpp
+++ b/libk9copy/backupdlg.cpp
@@ -9,134 +9,134 @@
#include "backupdlg.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qprogressbar.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqprogressbar.h>
#include <kpushbutton.h>
-#include <qframe.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqframe.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "kpushbutton.h"
/*
* Constructs a backupDlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-backupDlg::backupDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
- : QDialog( parent, name, modal, fl )
+backupDlg::backupDlg( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
+ : TQDialog( tqparent, name, modal, fl )
{
if ( !name )
setName( "backupDlg" );
- setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
- setMinimumSize( QSize( 0, 0 ) );
- setMaximumSize( QSize( 9999, 9999 ) );
- setBaseSize( QSize( 500, 230 ) );
- setCursor( QCursor( 3 ) );
+ tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
+ setMinimumSize( TQSize( 0, 0 ) );
+ setMaximumSize( TQSize( 9999, 9999 ) );
+ setBaseSize( TQSize( 500, 230 ) );
+ setCursor( TQCursor( 3 ) );
setModal( TRUE );
- backupDlgLayout = new QGridLayout( this, 1, 1, 3, 8, "backupDlgLayout");
+ backupDlgLayout = new TQGridLayout( this, 1, 1, 3, 8, "backupDlgLayout");
- textLabel1 = new QLabel( this, "textLabel1" );
- textLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
- textLabel1->setCursor( QCursor( 3 ) );
- textLabel1->setFrameShape( QLabel::NoFrame );
- textLabel1->setFrameShadow( QLabel::Raised );
+ textLabel1 = new TQLabel( this, "textLabel1" );
+ textLabel1->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
+ textLabel1->setCursor( TQCursor( 3 ) );
+ textLabel1->setFrameShape( TQLabel::NoFrame );
+ textLabel1->setFrameShadow( TQLabel::Raised );
backupDlgLayout->addMultiCellWidget( textLabel1, 0, 0, 0, 3 );
- layout3 = new QVBoxLayout( 0, 0, 6, "layout3");
+ tqlayout3 = new TQVBoxLayout( 0, 0, 6, "tqlayout3");
- lblStep = new QLabel( this, "lblStep" );
- lblStep->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, lblStep->sizePolicy().hasHeightForWidth() ) );
- QFont lblStep_font( lblStep->font() );
+ lblStep = new TQLabel( this, "lblStep" );
+ lblStep->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, lblStep->sizePolicy().hasHeightForWidth() ) );
+ TQFont lblStep_font( lblStep->font() );
lblStep_font.setItalic( TRUE );
lblStep->setFont( lblStep_font );
- lblStep->setCursor( QCursor( 3 ) );
- layout3->addWidget( lblStep );
+ lblStep->setCursor( TQCursor( 3 ) );
+ tqlayout3->addWidget( lblStep );
- pbStep = new QProgressBar( this, "pbStep" );
- pbStep->setCursor( QCursor( 3 ) );
- layout3->addWidget( pbStep );
+ pbStep = new TQProgressBar( this, "pbStep" );
+ pbStep->setCursor( TQCursor( 3 ) );
+ tqlayout3->addWidget( pbStep );
- pbTotal = new QProgressBar( this, "pbTotal" );
- pbTotal->setCursor( QCursor( 3 ) );
+ pbTotal = new TQProgressBar( this, "pbTotal" );
+ pbTotal->setCursor( TQCursor( 3 ) );
pbTotal->setMargin( 0 );
pbTotal->setTotalSteps( 4400 );
pbTotal->setPercentageVisible( TRUE );
- layout3->addWidget( pbTotal );
+ tqlayout3->addWidget( pbTotal );
- backupDlgLayout->addMultiCellLayout( layout3, 3, 3, 0, 3 );
+ backupDlgLayout->addMultiCellLayout( tqlayout3, 3, 3, 0, 3 );
- textLabel1_2 = new QLabel( this, "textLabel1_2" );
- textLabel1_2->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, textLabel1_2->sizePolicy().hasHeightForWidth() ) );
- textLabel1_2->setCursor( QCursor( 3 ) );
+ textLabel1_2 = new TQLabel( this, "textLabel1_2" );
+ textLabel1_2->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, textLabel1_2->sizePolicy().hasHeightForWidth() ) );
+ textLabel1_2->setCursor( TQCursor( 3 ) );
backupDlgLayout->addWidget( textLabel1_2, 2, 0 );
- lblTime = new QLabel( this, "lblTime" );
- lblTime->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)5, 0, 0, lblTime->sizePolicy().hasHeightForWidth() ) );
- lblTime->setCursor( QCursor( 3 ) );
+ lblTime = new TQLabel( this, "lblTime" );
+ lblTime->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)5, 0, 0, lblTime->sizePolicy().hasHeightForWidth() ) );
+ lblTime->setCursor( TQCursor( 3 ) );
backupDlgLayout->addWidget( lblTime, 2, 1 );
- layout1 = new QHBoxLayout( 0, 0, 6, "layout1");
- spacer1 = new QSpacerItem( 131, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
- layout1->addItem( spacer1 );
+ tqlayout1 = new TQHBoxLayout( 0, 0, 6, "tqlayout1");
+ spacer1 = new TQSpacerItem( 131, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
+ tqlayout1->addItem( spacer1 );
bAbort = new KPushButton( this, "bAbort" );
- bAbort->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, bAbort->sizePolicy().hasHeightForWidth() ) );
- bAbort->setCursor( QCursor( 0 ) );
+ bAbort->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, bAbort->sizePolicy().hasHeightForWidth() ) );
+ bAbort->setCursor( TQCursor( 0 ) );
bAbort->setProperty( "stdItem", 26 );
- layout1->addWidget( bAbort );
+ tqlayout1->addWidget( bAbort );
- backupDlgLayout->addMultiCellLayout( layout1, 4, 4, 0, 3 );
+ backupDlgLayout->addMultiCellLayout( tqlayout1, 4, 4, 0, 3 );
- lblFactor = new QLabel( this, "lblFactor" );
- lblFactor->setCursor( QCursor( 3 ) );
+ lblFactor = new TQLabel( this, "lblFactor" );
+ lblFactor->setCursor( TQCursor( 3 ) );
backupDlgLayout->addWidget( lblFactor, 2, 3 );
- frame3 = new QFrame( this, "frame3" );
- frame3->setCursor( QCursor( 3 ) );
- frame3->setFrameShape( QFrame::StyledPanel );
- frame3->setFrameShadow( QFrame::Raised );
+ frame3 = new TQFrame( this, "frame3" );
+ frame3->setCursor( TQCursor( 3 ) );
+ frame3->setFrameShape( TQFrame::StyledPanel );
+ frame3->setFrameShadow( TQFrame::Raised );
frame3->setMargin( 1 );
- frame3Layout = new QGridLayout( frame3, 1, 1, 2, 6, "frame3Layout");
+ frame3Layout = new TQGridLayout( frame3, 1, 1, 2, 6, "frame3Layout");
bPlay = new KPushButton( frame3, "bPlay" );
- bPlay->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, bPlay->sizePolicy().hasHeightForWidth() ) );
- bPlay->setMinimumSize( QSize( 25, 25 ) );
- bPlay->setMaximumSize( QSize( 25, 25 ) );
- bPlay->setCursor( QCursor( 0 ) );
+ bPlay->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, bPlay->sizePolicy().hasHeightForWidth() ) );
+ bPlay->setMinimumSize( TQSize( 25, 25 ) );
+ bPlay->setMaximumSize( TQSize( 25, 25 ) );
+ bPlay->setCursor( TQCursor( 0 ) );
bPlay->setToggleButton( TRUE );
bPlay->setOn( TRUE );
bPlay->setFlat( FALSE );
frame3Layout->addWidget( bPlay, 1, 1 );
- spacer4 = new QSpacerItem( 476, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer4 = new TQSpacerItem( 476, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
frame3Layout->addItem( spacer4, 1, 0 );
- image = new QLabel( frame3, "image" );
- image->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, image->sizePolicy().hasHeightForWidth() ) );
- image->setPaletteBackgroundColor( QColor( 0, 0, 0 ) );
- image->setCursor( QCursor( 3 ) );
+ image = new TQLabel( frame3, "image" );
+ image->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, image->sizePolicy().hasHeightForWidth() ) );
+ image->setPaletteBackgroundColor( TQColor( 0, 0, 0 ) );
+ image->setCursor( TQCursor( 3 ) );
image->setScaledContents( TRUE );
frame3Layout->addMultiCellWidget( image, 0, 0, 0, 1 );
backupDlgLayout->addMultiCellWidget( frame3, 1, 1, 0, 3 );
- spacer3 = new QSpacerItem( 380, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer3 = new TQSpacerItem( 380, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
backupDlgLayout->addItem( spacer3, 2, 2 );
languageChange();
- resize( QSize(385, 425).expandedTo(minimumSizeHint()) );
+ resize( TQSize(385, 425).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( bAbort, SIGNAL( clicked() ), this, SLOT( bAbortClick() ) );
+ connect( bAbort, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bAbortClick() ) );
}
/*
@@ -144,7 +144,7 @@ backupDlg::backupDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
*/
backupDlg::~backupDlg()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -158,7 +158,7 @@ void backupDlg::languageChange()
lblStep->setText( tr2i18n( "Current step" ) );
textLabel1_2->setText( tr2i18n( "Elapsed Time" ) );
lblTime->setText( tr2i18n( "--:--:--" ) );
- bPlay->setText( QString::null );
+ bPlay->setText( TQString() );
}
void backupDlg::bAbortClick()
@@ -9,134 +9,134 @@
#include "kpushbutton.h"
/*
- * Constructs a backupDlg as a child of 'parent', with the
+ * Constructs a backupDlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
@@ -144,7 +144,7 @@ backupDlg::backupDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
backupDlg::~backupDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*